Query and download PIT tag data about night passage and re-ascension at particular dams for specific species and year, using DART.

queryPITtagData(
  damPIT = c("GRA", "PRA", "RIA", "RRF"),
  spp = c("Chinook", "Coho", "Steelhead", "Sockeye"),
  start_date = NULL,
  end_date = NULL
)

Arguments

damPIT

the dam code for the dam you wish to query for PIT tag data. Currently only available for Lower Granite Dam (GRA), Priest Rapids (PRA), Rock Island (RIA) and Rocky Reach (RRF).

spp

species to query PIT tag observations for. Possible choices are: `Chinook`, `Coho`, `Steelhead`, `Sockeye`

start_date

character vector of date (YYYYMMDD) when query should start

end_date

character vector of date (YYYYMMDD) when query should end

Author

Kevin See

Examples

queryPITtagData(spp = "Steelhead", start_date = "20180701")
#> # A tibble: 29,774 × 25
#>    Ladder  Year Species   SpCode TagId  WindowDetectionFlag ClockHour Date      
#>    <chr>  <dbl> <chr>      <dbl> <chr>                <dbl> <chr>     <date>    
#>  1 GRA     2019 Steelhead      3 3DD.0…                   1 0600      2018-07-01
#>  2 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  3 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  4 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  5 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  6 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  7 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  8 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#>  9 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#> 10 GRA     2019 Steelhead      3 3DD.0…                   0 0600      2018-07-01
#> # ℹ 29,764 more rows
#> # ℹ 17 more variables: WindowCountHours <chr>, Period <chr>, RearType <chr>,
#> #   TagStage <chr>, Coil <chr>, DetectionDateTime <dttm>, TravelTime <dbl>,
#> #   TagIdAscentCount <dbl>, ReleaseYear <dbl>, ReleaseDateTime <dttm>,
#> #   Run <dbl>, Length <dbl>, CaptureMethod <chr>, FlagCodes <chr>,
#> #   ReleaseSite <chr>, TagFile <chr>, ReleaseRKM <chr>